@@ -1,7 +1,7 @@
 package Test::WithDB;
 
 our $DATE = '2015-04-22'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -97,7 +97,7 @@ sub create_db {
     push @{ $self->{_created_dbs}  }, $dbname;
 
     my $dsn = $cfg->{user_dsn};
-    $dsn =~ s/dbname=[^;]+//;
+    $dsn =~ s/dbname=[^;]*//;
     if ($self->{_driver} eq 'SQLite') {
         my $dir = $cfg->{sqlite_db_dir} // '.';
         $dsn .= ";dbname=$dir/$dbname";
@@ -193,7 +193,7 @@ Test::WithDB - Framework for testing application using database
 
 =head1 VERSION
 
-This document describes version 0.04 of Test::WithDB (from Perl distribution Test-WithDB), released on 2015-04-22.
+This document describes version 0.05 of Test::WithDB (from Perl distribution Test-WithDB), released on 2015-04-22.
 
 =head1 SYNOPSIS
 
